@@ -66,7 +66,6 @@ html_theme_options = {
             "icon": "fa-brands fa-discord",
         },
     ],
-    "analytics": {"google_analytics_id": "G-L0C8PGT2LM"},
     "pygment_light_style": "material",
     "pygment_dark_style": "material",
     "header_links_before_dropdown": 5,
@@ -90,10 +89,17 @@ napoleon_numpy_docstring = True
 myst_enable_extensions = ["colon_fence", "deflist"]
 
 gallery_endpoint = 'panel-gallery-dev' if is_dev else 'panel-gallery'
-gallery_url = f'https://{gallery_endpoint}.holoviz.dsp.anaconda.com'
+gallery_url = f'https://{gallery_endpoint}.holoviz-demo.anaconda.com'
 jlite_url = 'https://holoviz-dev.github.io/panelite-dev' if is_dev else 'https://panelite.holoviz.org'
 pyodide_url = 'https://holoviz-dev.github.io/panel/pyodide' if is_dev else 'https://panel.holoviz.org/pyodide'
 
+rediraffe_redirects = {
+    'user_guide/APIs': 'explanation/api/index',
+    'user_guide/Pipelines': 'how_to/pipeline/index',
+    'user_guide/Templates': 'how_to/templates/index',
+    'user_guide/Server_Configuration': 'how_to/server/index',
+}
+
 nbsite_analytics = {
     'goatcounter_holoviz': True,
 }
