@@ -15,7 +15,7 @@ from inspect import (
 )
 from io import BytesIO
 from typing import (
-    TYPE_CHECKING, Any, Callable, ClassVar, Dict, List, Literal,
+    TYPE_CHECKING, Any, Callable, ClassVar, Literal,
 )
 
 import param
@@ -185,7 +185,7 @@ class ChatFeed(ListPanel):
     _disabled_stack = param.List(doc="""
         The previous disabled state of the feed.""")
 
-    _stylesheets: ClassVar[List[str]] = [f"{CDN_DIST}css/chat_feed.css"]
+    _stylesheets: ClassVar[list[str]] = [f"{CDN_DIST}css/chat_feed.css"]
 
     def __init__(self, *objects, **params):
         self._callback_future = None
@@ -273,7 +273,7 @@ class ChatFeed(ListPanel):
         return model
 
     def _update_model(
-        self, events: Dict[str, param.parameterized.Event], msg: Dict[str, Any],
+        self, events: dict[str, param.parameterized.Event], msg: dict[str, Any],
         root: Model, model: Model, doc: Document, comm: Comm | None
     ) -> None:
         return
@@ -327,6 +327,7 @@ class ChatFeed(ListPanel):
         value: dict,
         user: str | None = None,
         avatar: str | bytes | BytesIO | None = None,
+        **input_message_params
     ) -> ChatMessage | None:
         """
         Builds a ChatMessage from the value.
@@ -347,6 +348,7 @@ class ChatFeed(ListPanel):
             message_params["avatar"] = avatar
         if self.width:
             message_params["width"] = int(self.width - 80)
+        message_params.update(input_message_params)
 
         message = ChatMessage(**message_params)
         return message
@@ -547,6 +549,7 @@ class ChatFeed(ListPanel):
         user: str | None = None,
         avatar: str | bytes | BytesIO | None = None,
         respond: bool = True,
+        **message_params
     ) -> ChatMessage | None:
         """
         Sends a value and creates a new message in the chat log.
@@ -563,6 +566,8 @@ class ChatFeed(ListPanel):
             The avatar to use; overrides the message message's avatar if provided.
         respond : bool
             Whether to execute the callback.
+        message_params : dict
+            Additional parameters to pass to the ChatMessage.
 
         Returns
         -------
@@ -578,7 +583,7 @@ class ChatFeed(ListPanel):
         else:
             if not isinstance(value, dict):
                 value = {"object": value}
-            message = self._build_message(value, user=user, avatar=avatar)
+            message = self._build_message(value, user=user, avatar=avatar, **message_params)
         self.append(message)
         if respond:
             self.respond()
@@ -591,6 +596,7 @@ class ChatFeed(ListPanel):
         avatar: str | bytes | BytesIO | None = None,
         message: ChatMessage | None = None,
         replace: bool = False,
+        **message_params
     ) -> ChatMessage | None:
         """
         Streams a token and updates the provided message, if provided.
@@ -613,6 +619,8 @@ class ChatFeed(ListPanel):
             The message to update.
         replace : bool
             Whether to replace the existing text when streaming a string or dict.
+        message_params : dict
+            Additional parameters to pass to the ChatMessage.
 
         Returns
         -------
@@ -635,6 +643,9 @@ class ChatFeed(ListPanel):
                     message.avatar = avatar
             else:
                 message.update(value, user=user, avatar=avatar)
+
+            if message_params:
+                message.param.update(**message_params)
             return message
 
         if isinstance(value, ChatMessage):
@@ -642,7 +653,7 @@ class ChatFeed(ListPanel):
         else:
             if not isinstance(value, dict):
                 value = {"object": value}
-            message = self._build_message(value, user=user, avatar=avatar)
+            message = self._build_message(value, user=user, avatar=avatar, **message_params)
         self._replace_placeholder(message)
         return message
 
@@ -676,7 +687,7 @@ class ChatFeed(ListPanel):
             self._replace_placeholder(None)
         return cancelled
 
-    def undo(self, count: int = 1) -> List[Any]:
+    def undo(self, count: int = 1) -> list[Any]:
         """
         Removes the last `count` of messages from the chat log and returns them.
 
@@ -696,7 +707,7 @@ class ChatFeed(ListPanel):
         self._chat_log.objects = messages[:-count]
         return undone_entries
 
-    def clear(self) -> List[Any]:
+    def clear(self) -> list[Any]:
         """
         Clears the chat log and returns the messages that were cleared.
 
@@ -710,11 +721,11 @@ class ChatFeed(ListPanel):
 
     def _serialize_for_transformers(
         self,
-        messages: List[ChatMessage],
-        role_names: Dict[str, str | List[str]] | None = None,
+        messages: list[ChatMessage],
+        role_names: dict[str, str | list[str]] | None = None,
         default_role: str | None = "assistant",
         custom_serializer: Callable = None
-    ) -> List[Dict[str, Any]]:
+    ) -> list[dict[str, Any]]:
         """
         Exports the chat log for use with transformers.
         """
@@ -760,7 +771,7 @@ class ChatFeed(ListPanel):
 
     def serialize(
         self,
-        exclude_users: List[str] | None = None,
+        exclude_users: list[str] | None = None,
         filter_by: Callable | None = None,
         format: Literal["transformers"] = "transformers",
         custom_serializer: Callable | None = None,
