@@ -1,14 +1,16 @@
 from contextlib import contextmanager
-from urllib.parse import urlparse, urljoin
+from urllib.parse import urljoin, urlparse
 
-from bokeh.server.django.consumers import DocConsumer, AutoloadJsConsumer
+try:
+    from bokeh_django.consumers import AutoloadJsConsumer, DocConsumer
+except Exception:
+    from bokeh.server.django.consumers import AutoloadJsConsumer, DocConsumer
 
 from ..util import edit_readonly
 from .resources import Resources
+from .server import autoload_js_script, server_html_page_for_session
 from .state import state
-from .server import (
-    autoload_js_script, server_html_page_for_session,
-)
+
 
 async def doc_handle(self, body):
     session = await self._get_session()
@@ -59,12 +61,15 @@ async def autoload_handle(self, body):
         absolute_url = self.get_argument("bokeh-absolute-url", default=None)
 
         if absolute_url:
-            server_url = '{uri.scheme}://{uri.netloc}/'.format(uri=urlparse(absolute_url))
+            server_url = f'{urlparse(absolute_url).scheme}://{urlparse(absolute_url).netloc}/'
         else:
             server_url = None
 
+        absolute = server_url not in absolute_url
         resources = self.resources(server_url)
-        js = autoload_js_script(session.document, resources, session.token, element_id, app_path, absolute_url)
+        js = autoload_js_script(
+            session.document, resources, session.token, element_id, app_path, absolute_url, absolute=absolute
+        )
 
     headers = [
         (b"Access-Control-Allow-Headers", b"*"),
