@@ -15,7 +15,7 @@ import weakref
 from contextlib import contextmanager
 from functools import partial, wraps
 from typing import (
-    TYPE_CHECKING, Any, Callable, Dict, Iterator, List, Optional,
+    TYPE_CHECKING, Any, Callable, Iterator, Optional,
 )
 
 from bokeh.application.application import SessionContext
@@ -59,6 +59,8 @@ def WRITE_LOCK():
 _panel_last_cleanup = None
 _write_tasks = []
 
+extra_socket_handlers = {}
+
 @dataclasses.dataclass
 class Request:
     headers : dict
@@ -87,7 +89,7 @@ def _cleanup_task(task):
     if task in _write_tasks:
         _write_tasks.remove(task)
 
-def _dispatch_events(doc: Document, events: List[DocumentChangedEvent]) -> None:
+def _dispatch_events(doc: Document, events: list[DocumentChangedEvent]) -> None:
     """
     Handles dispatch of events which could not be processed in
     unlocked decorator.
@@ -177,6 +179,8 @@ async def _dispatch_msgs(doc, msgs):
             continue
         if isinstance(conn._socket, WebSocketHandler):
             futures = dispatch_tornado(conn, msg=msg)
+        elif (socket_type:= type(conn._socket)) in extra_socket_handlers:
+            futures = extra_socket_handlers[socket_type](conn, msg=msg)
         else:
             futures = dispatch_django(conn, msg=msg)
         await _run_write_futures(futures)
@@ -405,6 +409,8 @@ def unlocked() -> Iterator:
                 continue
             elif isinstance(conn._socket, WebSocketHandler):
                 futures += dispatch_tornado(conn, dispatch_events)
+            elif (socket_type:= type(conn._socket)) in extra_socket_handlers:
+                futures += extra_socket_handlers[socket_type](conn, dispatch_events)
             else:
                 futures += dispatch_django(conn, dispatch_events)
 
@@ -474,7 +480,7 @@ def immediate_dispatch(doc: Document | None = None):
     doc.callbacks._held_events = old_events
 
 @contextmanager
-def freeze_doc(doc: Document, model: HasProps, properties: Dict[str, Any], force: bool = False):
+def freeze_doc(doc: Document, model: HasProps, properties: dict[str, Any], force: bool = False):
     """
     Freezes the document model references if any of the properties
     are themselves a model.
