@@ -10,9 +10,7 @@ import pathlib
 import sys
 import uuid
 
-from typing import (
-    Any, Callable, List, Tuple,
-)
+from typing import Any, Callable
 
 import bokeh
 import js
@@ -137,7 +135,7 @@ def async_execute(func: Any):
 
 param.parameterized.async_executor = async_execute
 
-def _doc_json(doc: Document, root_els=None) -> Tuple[str, str, str]:
+def _doc_json(doc: Document, root_els=None) -> tuple[str, str, str]:
     """
     Serializes a Bokeh Document into JSON representations of the entire
     Document, the individual render_items and the ids of DOM nodes to
@@ -169,7 +167,7 @@ def _doc_json(doc: Document, root_els=None) -> Tuple[str, str, str]:
         })
     return json.dumps(docs_json), json.dumps(render_items_json), json.dumps(root_ids)
 
-def _model_json(model: Model, target: str) -> Tuple[Document, str]:
+def _model_json(model: Model, target: str) -> tuple[Document, str]:
     """
     Renders a Bokeh Model to JSON representation given a particular
     DOM target and returns the Document and the serialized JSON string.
@@ -239,7 +237,7 @@ def _serialize_buffers(obj, buffers={}):
             return obj.to_base64()
     return obj
 
-def _process_document_events(doc: Document, events: List[Any]):
+def _process_document_events(doc: Document, events: list[Any]):
     serializer = Serializer(references=doc.models.synced_references)
     patch_json = PatchJson(events=serializer.encode(events))
     doc.models.flush_synced()
@@ -533,7 +531,7 @@ def sync_location():
             k: v for k, v in loc_data.items() if k in state.location.param
         })
 
-async def write_doc(doc: Document | None = None) -> Tuple[str, str, str]:
+async def write_doc(doc: Document | None = None) -> tuple[str, str, str]:
     """
     Renders the contents of the Document into an existing template.
     Note that this assumes that the HTML file this function runs in
