@@ -40,13 +40,17 @@ def find_stack_level() -> int:
 
     frame = inspect.currentframe()
     stacklevel = 0
-    while frame:
-        fname = inspect.getfile(frame)
-        if fname.startswith((pkg_dir, param_dir)) and not fname.startswith(test_dir):
-            frame = frame.f_back
-            stacklevel += 1
-        else:
-            break
+    try:
+        while frame:
+            fname = inspect.getfile(frame)
+            if fname.startswith((pkg_dir, param_dir)) and not fname.startswith(test_dir):
+                frame = frame.f_back
+                stacklevel += 1
+            else:
+                break
+    finally:
+        # See: https://docs.python.org/3/library/inspect.html#inspect.Traceback
+        del frame
 
     return stacklevel
 
